@@ -3,26 +3,26 @@
 from typing import Dict
 import re
 from requests import Session
-from .auth import access_service
+from .auth import access_sso_service
 __all__ = ("access_mycqu",)
 
 MYCQU_TOKEN_INDEX_URL = "https://my.cqu.edu.cn/enroll/token-index"
 MYCQU_TOKEN_URL = "https://my.cqu.edu.cn/authserver/oauth/token"
 MYCQU_AUTHORIZE_URL = f"https://my.cqu.edu.cn/authserver/oauth/authorize?client_id=enroll-prod&response_type=code&scope=all&state=&redirect_uri={MYCQU_TOKEN_INDEX_URL}"
-MYCQU_SERVICE_URL = "http://my.cqu.edu.cn/authserver/authentication/cas"
+MYCQU_SERVICE_URL = "https://my.cqu.edu.cn/authserver/authentication/cas"
 CODE_RE = re.compile(r"\?code=([^&]+)&")
 
 
 class MycquUnauthorized(Exception):
     def __init__(self):
-        super().__init__(
-            "Unanthorized in mycqu, please auth.login firstly and then mycqu.access_mycqu")
+        super().__init__("Unanthorized in mycqu, auth.login firstly and then mycqu.access_mycqu")
 
 
 def get_oauth_token(session: Session) -> str:
     # from https://github.com/CQULHW/CQUQueryGrade
     resp = session.get(MYCQU_AUTHORIZE_URL, allow_redirects=False)
-    assert (match := CODE_RE.search(resp.headers['Location']))
+    match = CODE_RE.search(resp.headers['Location'])
+    assert match
     token_data = {
         'client_id': 'enroll-prod',
         'client_secret': 'app-a-1234',
@@ -46,8 +46,7 @@ def access_mycqu(session: Session, add_to_header: bool = True) -> Dict[str, str]
     """
     if "Authorization" in session.headers:
         del session.headers["Authorization"]
-    session.get(access_service(session, MYCQU_SERVICE_URL).headers['Location'],
-                allow_redirects=False)  # http 302 to https
+    access_sso_service(session, MYCQU_SERVICE_URL)
     token = get_oauth_token(session)
     if add_to_header:
         session.headers["Authorization"] = token
